@@ -1,13 +1,14 @@
 package Scrappy::Scraper;
 
 BEGIN {
-    $Scrappy::Scraper::VERSION = '0.93111250';
+    $Scrappy::Scraper::VERSION = '0.94111260';
 }
 
 # load OO System
 use Moose;
 
 # load other libraries
+use Data::Dumper;
 use File::Util;
 use Scrappy::Logger;
 use Scrappy::Plugin;
@@ -262,6 +263,11 @@ sub download {
     return $self;
 }
 
+sub dumper {
+    shift;
+    return Data::Dumper::Dumper(@_);
+}
+
 sub form {
     my $self = shift;
     my $url  = URI->new($self->url);
